Top-level namespace for running simulations.
Top-level namespace for running simulations.
(expand-test test)Expands a test with default options.
Expands a test with default options.
(run test)Takes test parameters and returns a test with a completed :history field. Parameters are a map of:
{; Database parameters :db One of :si, :prefix, etc: the name of a DB
; Generator parameters :generator The name of the generator to use, e.g. :list-append :key-count Number of distinct keys at any point :min-txn-length Minimum number of operations per txn :max-txn-length Maximum number of operations per txn :max-writes-per-key Maximum number of operations per key :concurrency Number of concurrent clients :limit Number of invocations to generate
; Randomness :seed A long: the random seed to use}
This function will load an earlier run from disk cache, if possible.
Takes test parameters and returns a test with a completed :history field.
Parameters are a map of:
{; Database parameters
:db One of :si, :prefix, etc: the name of a DB
; Generator parameters
:generator The name of the generator to use, e.g. :list-append
:key-count Number of distinct keys at any point
:min-txn-length Minimum number of operations per txn
:max-txn-length Maximum number of operations per txn
:max-writes-per-key Maximum number of operations per key
:concurrency Number of concurrent clients
:limit Number of invocations to generate
; Randomness
:seed A long: the random seed to use}
This function will load an earlier run from disk cache, if possible.(run! test)Like run, but actually runs the simulator instead of potentially loading from cache. Saves to cache as a side effect.
Like run, but actually runs the simulator instead of potentially loading from cache. Saves to cache as a side effect.
(with-rand seed & body)Takes a seed long and evaluates body with an RNG initialized to that seed.
Takes a seed long and evaluates body with an RNG initialized to that seed.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |