Caches histories as EDN on disk.
Caches histories as EDN on disk.
Directory in which we store cached histories.
Directory in which we store cached histories.
(chunk-file! test chunk-number)Returns the file for a test and chunk number. Creates parent directory if necessary.
Returns the file for a test and chunk number. Creates parent directory if necessary.
How big is each chunk of the history?
How big is each chunk of the history?
(dir test)Takes a test map and computes the File for the directory we store it in.
Takes a test map and computes the File for the directory we store it in.
(load test)Takes a test, returns test with :history lazily loaded from disk. Returns nil if not cached.
Takes a test, returns test with :history lazily loaded from disk. Returns nil if not cached.
(load-chunk test chunk-number)Loads a chunk of a test's history into a vector.
Loads a chunk of a test's history into a vector.
(reader! test chunk-number)Opens a Fressian reader for a test and chunk number.
Opens a Fressian reader for a test and chunk number.
(write! test)Writes a completed test (with :history) to disk. Deletes all test files first. Returns test.
Writes a completed test (with :history) to disk. Deletes all test files first. Returns test.
(writer! test chunk-number)Opens a Fressian writer for a test and chunk number.
Opens a Fressian writer for a test and chunk number.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |