Takes databases and generators and runs them, producing histories.
Takes databases and generators and runs them, producing histories.
(brand-nth xs)Rand-nth on a Bifurcan collection. Returns nil on empty colls.
Rand-nth on a Bifurcan collection. Returns nil on empty colls.
(simulate test)Takes a map with the following keys:
{:concurrency The number of concurrent clients :db The database to execute against :generator A sequence of invocations to perform}
Launches simulated clients with the given concurrency, which draw operations from the generator and apply them to the DB. Returns a Jepsen IHistory.
Deterministically random; uses data.generators/rnd.
Takes a map with the following keys:
{:concurrency The number of concurrent clients
:db The database to execute against
:generator A sequence of invocations to perform}
Launches simulated clients with the given concurrency, which draw operations
from the generator and apply them to the DB. Returns a Jepsen IHistory.
Deterministically random; uses data.generators/*rnd*.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |